package com.ebaiyihui.family.doctor.server.controller;


import com.ebaiyihui.family.doctor.common.dto.InsertPatientMedicalRecordDTO;
import com.ebaiyihui.family.doctor.common.dto.InvalidMedicalRecordDTO;
import com.ebaiyihui.family.doctor.common.dto.UpdatePatientMedicalRecordDTO;
import com.ebaiyihui.family.doctor.common.vo.InsertPatientMedicalRecordVO;
import com.ebaiyihui.family.doctor.common.vo.PatientMedicalRecordVO;
import com.ebaiyihui.family.doctor.server.service.PatientMedicalRecordService;
import com.ebaiyihui.framework.response.BaseResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Objects;

@RestController
@RequestMapping("/medicalRecord")
@Api(tags = "患者病历API")
public class PatientMedicalRecordController {

    @Autowired
    private PatientMedicalRecordService patientMedicalRecordService;

    @PostMapping("/insert")
    @ApiOperation(value = "新建复诊病历", notes = "医生开具复诊病历")
    public BaseResponse<InsertPatientMedicalRecordVO> insert(@RequestBody @Validated InsertPatientMedicalRecordDTO dto,
                                                             BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return BaseResponse.error(Objects.requireNonNull(bindingResult.getFieldError()).getDefaultMessage());
        }
        return patientMedicalRecordService.insertPatientMedicalRecord(dto);
    }

    @PostMapping("/update")
    @ApiOperation(value = "修改复诊病历", notes = "医生修改复诊病历")
    public BaseResponse<InsertPatientMedicalRecordVO> update(@RequestBody @Validated UpdatePatientMedicalRecordDTO dto,
                                                             BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return BaseResponse.error(Objects.requireNonNull(bindingResult.getFieldError()).getDefaultMessage());
        }
        return patientMedicalRecordService.updatePatientMedicalRecord(dto);
    }

    @PostMapping("/invalid")
    @ApiOperation(value = "开具处方失效病历", notes = "开具处方失效病历")
    public BaseResponse<Objects> invalid(@RequestBody @Validated InvalidMedicalRecordDTO dto,
                                         BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return BaseResponse.error(Objects.requireNonNull(bindingResult.getFieldError()).getDefaultMessage());
        }
        return patientMedicalRecordService.invalidMedicalRecord(dto);
    }

    @PostMapping("/detail")
    @ApiOperation(value = "复诊病历详情", notes = "复诊病历详情")
    public BaseResponse<PatientMedicalRecordVO> detail(@RequestBody @Validated InvalidMedicalRecordDTO dto,
                                                       BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return BaseResponse.error(Objects.requireNonNull(bindingResult.getFieldError()).getDefaultMessage());
        }
        return patientMedicalRecordService.detailMedicalRecord(dto);
    }

}
