package com.ebaiyihui.family.doctor.server.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ebaiyihui.family.doctor.common.dto.InsertPatientMedicalRecordDTO;
import com.ebaiyihui.family.doctor.common.dto.InvalidMedicalRecordDTO;
import com.ebaiyihui.family.doctor.common.dto.UpdatePatientMedicalRecordDTO;
import com.ebaiyihui.family.doctor.common.vo.InsertPatientMedicalRecordVO;
import com.ebaiyihui.family.doctor.common.vo.PatientInfoVo;
import com.ebaiyihui.family.doctor.common.vo.PatientMedicalRecordVO;
import com.ebaiyihui.family.doctor.server.entity.PatientEntity;
import com.ebaiyihui.family.doctor.server.entity.PatientMedicalRecordEntity;
import com.ebaiyihui.family.doctor.server.entity.PatientSignEntity;
import com.ebaiyihui.family.doctor.server.exception.BusinessException;
import com.ebaiyihui.family.doctor.server.mapper.PatientMapper;
import com.ebaiyihui.family.doctor.server.mapper.PatientMedicalRecordMapper;
import com.ebaiyihui.family.doctor.server.mapper.PatientSignMapper;
import com.ebaiyihui.family.doctor.server.service.PatientMedicalRecordService;
import com.ebaiyihui.family.doctor.server.util.IDCardUtil;
import com.ebaiyihui.family.doctor.server.util.UUIDUtil;
import com.ebaiyihui.framework.response.BaseResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Objects;

@Service
@Slf4j
public class PatientMedicalRecordServiceImpl implements PatientMedicalRecordService {

    @Autowired
    private PatientMedicalRecordMapper patientMedicalRecordMapper;

    @Autowired
    private PatientMapper patientMapper;

    @Autowired
    private PatientSignMapper patientSignMapper;


    @Override
    public BaseResponse<InsertPatientMedicalRecordVO> insertPatientMedicalRecord(InsertPatientMedicalRecordDTO dto) {
        log.info("医生开具复诊病历入参:{}", dto.toString());
        PatientMedicalRecordEntity entity = new PatientMedicalRecordEntity();
        BeanUtils.copyProperties(dto, entity);
        entity.setId(UUIDUtil.getUUID());
        entity.setRecordStatus(1);
        patientMedicalRecordMapper.insert(entity);
        InsertPatientMedicalRecordVO vo = new InsertPatientMedicalRecordVO();
        vo.setRecordId(String.valueOf(entity.getId()));
        return BaseResponse.success(vo);
    }

    @Override
    public BaseResponse<InsertPatientMedicalRecordVO> updatePatientMedicalRecord(UpdatePatientMedicalRecordDTO dto) {
        log.info("医生修改复诊病历入参:{}", dto.toString());
        if (StringUtils.isEmpty(dto.getId())){
            throw new BusinessException("修改xid不能为空");
        }
        PatientMedicalRecordEntity recordEntity = patientMedicalRecordMapper.getByIdAndStatus(dto.getId(),1);
        if (ObjectUtil.isNull(recordEntity)){
            throw new BusinessException("未找到该病历，或病例失效");
        }
        PatientMedicalRecordEntity entity = new PatientMedicalRecordEntity();
        BeanUtils.copyProperties(dto, entity);
        patientMedicalRecordMapper.updateById(entity);
        InsertPatientMedicalRecordVO vo = new InsertPatientMedicalRecordVO();
        vo.setRecordId(String.valueOf(entity.getId()));
        return BaseResponse.success(vo);
    }

    @Override
    public BaseResponse<Objects> invalidMedicalRecord(InvalidMedicalRecordDTO dto) {
        log.info("开具处方失效病历入参:{}", dto.toString());
        if (StringUtils.isEmpty(dto.getId())){
            throw new BusinessException("病历id不能未空");
        }
        PatientMedicalRecordEntity recordEntity = patientMedicalRecordMapper.getByIdAndStatus(dto.getId(),1);
        if (ObjectUtil.isNull(recordEntity)){
            throw new BusinessException("未找到该病历，或病例失效");
        }

        PatientMedicalRecordEntity entity = new PatientMedicalRecordEntity();
        entity.setId(dto.getId());
        entity.setRecordStatus(0);
        patientMedicalRecordMapper.updateById(entity);
        return BaseResponse.success();
    }

    @Override
    public BaseResponse<PatientMedicalRecordVO> detailMedicalRecord(InvalidMedicalRecordDTO dto) {
        log.info("病历详情入参:{}", dto.toString());
        if (StringUtils.isEmpty(dto.getId())){
            throw new BusinessException("病历id不能未空");
        }
        PatientMedicalRecordEntity entity = patientMedicalRecordMapper.getByIdAndStatus(dto.getId(),1);
        if (ObjectUtil.isNull(entity)){
            throw new BusinessException("未找到该病历，或病例失效");
        }
        PatientMedicalRecordVO vo = new PatientMedicalRecordVO();
        BeanUtils.copyProperties(entity, vo);

        // 查询患者，医生，科室信息
        PatientMedicalRecordVO.InfoVo infoVo = new PatientMedicalRecordVO.InfoVo();
        PatientEntity patientEntity = patientMapper.selectById(entity.getPatientId());
        if (ObjectUtil.isNotNull(patientEntity)){
            infoVo.setPatientName(patientEntity.getPatientName());
            infoVo.setPatientGender(String.valueOf(patientEntity.getGender()));
            infoVo.setPatientNo(patientEntity.getCredNo());
            infoVo.setPatientPhone(patientEntity.getPhone());
            infoVo.setPatientUserId(patientEntity.getUserId());
            infoVo.setPatientCredNo(patientEntity.getCredNo());
        }
        PatientSignEntity patientSignEntity = patientSignMapper.queryByAdmId(entity.getAdmId());
        if (ObjectUtil.isNotNull(patientSignEntity)){
            infoVo.setDeptId(String.valueOf(patientSignEntity.getDeptId()));
            infoVo.setDeptName(patientSignEntity.getDeptName());
            infoVo.setDoctorId(String.valueOf(patientSignEntity.getDoctorId()));
            infoVo.setDoctorName(patientSignEntity.getDoctorName());
        }
        vo.setInfoVo(infoVo);
        return BaseResponse.success(vo);
    }
}
